@@ -19,9 +19,8 @@ func TestGetApps(t *testing.T) {
 	am := NewAppMonitor()
 	hm := NewHookManager()
 	settings := cli.NewContext(nil, flag.NewFlagSet("", 0), nil)
-	httpClient, err := NewHTTPClient(false)
-	require.NoError(t, err)
-	sa := NewStorkAgent(settings, am, httpClient, hm)
+	httpClient := NewHTTPClient()
+	sa := NewStorkAgent(settings, am, httpClient, httpClient, hm)
 	am.Start(sa)
 	apps := am.GetApps()
 	require.Len(t, apps, 0)
@@ -159,15 +158,15 @@ func TestDetectApps(t *testing.T) {
 	am := &appMonitor{}
 	hm := NewHookManager()
 	settings := cli.NewContext(nil, flag.NewFlagSet("", 0), nil)
-	httpClient, _ := NewHTTPClient(false)
-	sa := NewStorkAgent(settings, am, httpClient, hm)
+	httpClient := NewHTTPClient()
+	sa := NewStorkAgent(settings, am, httpClient, httpClient, hm)
 	am.detectApps(sa)
 }
 
 // Test that detectAllowedLogs does not panic when Kea server is unreachable.
 func TestDetectAllowedLogsKeaUnreachable(t *testing.T) {
 	am := &appMonitor{}
-	httpClient, _ := NewHTTPClient(false)
+	httpClient := NewHTTPClient()
 	am.apps = append(am.apps, &KeaApp{
 		BaseApp: BaseApp{
 			Type: AppTypeKea,
@@ -185,7 +184,7 @@ func TestDetectAllowedLogsKeaUnreachable(t *testing.T) {
 	hm := NewHookManager()
 
 	settings := cli.NewContext(nil, flag.NewFlagSet("", 0), nil)
-	sa := NewStorkAgent(settings, am, httpClient, hm)
+	sa := NewStorkAgent(settings, am, httpClient, httpClient, hm)
 
 	require.NotPanics(t, func() { am.detectAllowedLogs(sa) })
 }
@@ -285,7 +284,7 @@ func TestDetectKeaApp(t *testing.T) {
 		require.Empty(t, ctrlPoint.Key)
 	}
 
-	httpClient, _ := NewHTTPClient(false)
+	httpClient := NewHTTPClient()
 
 	t.Run("config file without include statement", func(t *testing.T) {
 		tmpFilePath, clean := makeKeaConfFile()
@@ -454,7 +453,7 @@ func TestDetectConfiguredDaemons(t *testing.T) {
 	configPath, clean := makeKeaConfFile()
 	defer clean()
 
-	httpClient, _ := NewHTTPClient(false)
+	httpClient := NewHTTPClient()
 
 	// Act
 	app := detectKeaApp([]string{"", "", configPath}, "", httpClient)
@@ -481,7 +480,7 @@ func TestDetectConfiguredSingleDaemon(t *testing.T) {
 		}
 	} }`)
 
-	httpClient, _ := NewHTTPClient(false)
+	httpClient := NewHTTPClient()
 
 	// Act
 	app := detectKeaApp([]string{"", "", configPath}, "", httpClient)
