@@ -93,6 +93,7 @@ func updateMachineFields(db *dbops.PgDB, dbMachine *dbmodel.Machine, m *agentcom
 	dbMachine.State.VirtualizationSystem = m.VirtualizationSystem
 	dbMachine.State.VirtualizationRole = m.VirtualizationRole
 	dbMachine.State.HostID = m.HostID
+	dbMachine.State.AgentUsesHTTPCredentials = m.AgentUsesHTTPCredentials
 	dbMachine.LastVisitedAt = m.LastVisitedAt
 	dbMachine.Error = m.Error
 	err := dbmodel.UpdateMachine(db, dbMachine)
@@ -106,7 +107,7 @@ func updateMachineFields(db *dbops.PgDB, dbMachine *dbmodel.Machine, m *agentcom
 // their type matches and if they have the same control port.  Return true if
 // equal, false otherwise.
 func appCompare(dbApp *dbmodel.App, app *agentcomm.App) bool {
-	if dbApp.Type != app.Type {
+	if dbApp.Type.String() != app.Type {
 		return false
 	}
 
@@ -162,9 +163,9 @@ func mergeNewAndOldApps(db *dbops.PgDB, dbMachine *dbmodel.Machine, discoveredAp
 	newKeaAppsCnt := 0
 	newBind9AppsCnt := 0
 	for _, app := range discoveredApps {
-		if app.Type == dbmodel.AppTypeKea {
+		if app.Type == dbmodel.AppTypeKea.String() {
 			newKeaAppsCnt++
-		} else if app.Type == dbmodel.AppTypeBind9 {
+		} else if app.Type == dbmodel.AppTypeBind9.String() {
 			newBind9AppsCnt++
 		}
 	}
@@ -182,8 +183,8 @@ func mergeNewAndOldApps(db *dbops.PgDB, dbMachine *dbmodel.Machine, discoveredAp
 			// we assume that this is the same app. If there are more apps of a given type than used to be,
 			// or there are less apps than it used to be we have to compare their access control information
 			// to identify matching ones.
-			if (app.Type == dbmodel.AppTypeKea && dbAppOld.Type == dbmodel.AppTypeKea && oldKeaAppsCnt == 1 && newKeaAppsCnt == 1) ||
-				(app.Type == dbmodel.AppTypeBind9 && dbAppOld.Type == dbmodel.AppTypeBind9 && oldBind9AppsCnt == 1 && newBind9AppsCnt == 1) ||
+			if (app.Type == dbmodel.AppTypeKea.String() && dbAppOld.Type.IsKea() && oldKeaAppsCnt == 1 && newKeaAppsCnt == 1) ||
+				(app.Type == dbmodel.AppTypeBind9.String() && dbAppOld.Type.IsBind9() && oldBind9AppsCnt == 1 && newBind9AppsCnt == 1) ||
 				appCompare(dbAppOld, app) {
 				dbApp = dbAppOld
 				matchedApps = append(matchedApps, dbApp)
@@ -196,7 +197,7 @@ func mergeNewAndOldApps(db *dbops.PgDB, dbMachine *dbmodel.Machine, discoveredAp
 				ID:        0,
 				MachineID: dbMachine.ID,
 				Machine:   dbMachine,
-				Type:      app.Type,
+				Type:      dbmodel.AppType(app.Type),
 			}
 		} else {
 			dbApp.Machine = dbMachine
@@ -253,6 +254,11 @@ func GetMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmo
 		return ""
 	}
 
+	// The Stork server doesn't gather the Stork agent configuration, so we cannot
+	// detect its change. It compares the current agent state and the database
+	// entry to only recognize the HTTP credentials state was changed.
+	isStorkAgentChanged := dbMachine.State.AgentUsesHTTPCredentials != state.AgentUsesHTTPCredentials
+
 	// store machine's state in db
 	err = updateMachineFields(db, dbMachine, state)
 	if err != nil {
@@ -277,7 +283,7 @@ func GetMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmo
 			if err == nil {
 				// Let's now identify new daemons or the daemons with updated
 				// configurations and schedule configuration reviews for them
-				conditionallyBeginKeaConfigReviews(dbApp, state, reviewDispatcher)
+				conditionallyBeginKeaConfigReviews(dbApp, state, reviewDispatcher, isStorkAgentChanged)
 			}
 		case dbmodel.AppTypeBind9:
 			bind9.GetAppState(ctx2, agents, dbApp, eventCenter)
@@ -302,23 +308,36 @@ func GetMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmo
 // This function iterates over the app's daemons and checks if a new config
 // review should be performed. It is performed when daemon's configuration
 // or dispatcher's signature has changed.
-func conditionallyBeginKeaConfigReviews(dbApp *dbmodel.App, state *kea.AppStateMeta, reviewDispatcher configreview.Dispatcher) {
+func conditionallyBeginKeaConfigReviews(dbApp *dbmodel.App, state *kea.AppStateMeta, reviewDispatcher configreview.Dispatcher, storkAgentConfigChanged bool) {
 	for i, daemon := range dbApp.Daemons {
 		// Let's make sure that the config pointer is set. It can be nil
 		// when the daemon is inactive.
 		if daemon.KeaDaemon == nil || daemon.KeaDaemon.Config == nil {
 			continue
 		}
+
+		var triggers configreview.Triggers
+		if storkAgentConfigChanged {
+			triggers = append(triggers, configreview.StorkAgentConfigModified)
+		}
+
+		isConfigModified := true
 		if state != nil && state.SameConfigDaemons != nil {
-			if ok := state.SameConfigDaemons[daemon.Name]; ok && state.SameConfigDaemons[daemon.Name] {
+			if isSame, ok := state.SameConfigDaemons[daemon.Name]; ok && isSame {
 				if daemon.ConfigReview != nil &&
 					daemon.ConfigReview.Signature == reviewDispatcher.GetSignature() {
 					// Configuration of this daemon hasn't changed and the dispatcher has
-					// no checkers modified since the last review. Skip the review.
-					continue
+					// no checkers modified since the last review. Skip the config modified trigger.
+					isConfigModified = false
 				}
 			}
 		}
-		_ = reviewDispatcher.BeginReview(dbApp.Daemons[i], configreview.ConfigModified, nil)
+		if isConfigModified {
+			triggers = append(triggers, configreview.ConfigModified)
+		}
+
+		if len(triggers) != 0 {
+			_ = reviewDispatcher.BeginReview(dbApp.Daemons[i], triggers, nil)
+		}
 	}
 }
