@@ -185,6 +185,7 @@ func SetupLogging() {
 type CommandExecutor interface {
 	Output(string, ...string) ([]byte, error)
 	LookPath(string) (string, error)
+	IsFileExist(string) bool
 }
 
 // Executes the given command in the operating system.
@@ -206,6 +207,15 @@ func (e *systemCommandExecutor) LookPath(command string) (string, error) {
 	return exec.LookPath(command)
 }
 
+// Looks for a given file. Returns true is the path exist, is accessible, and
+// points to a file.
+func (e *systemCommandExecutor) IsFileExist(path string) bool {
+	if stat, err := os.Stat(path); err == nil {
+		return stat.Mode().IsRegular()
+	}
+	return false
+}
+
 // Convert bytes to hex string.
 func BytesToHex(bytesArray []byte) string {
 	var buf bytes.Buffer
@@ -259,8 +269,7 @@ func ReadFileWithIncludes(path string) (string, error) {
 func readFileWithIncludes(path string, parentPaths map[string]bool) (string, error) {
 	raw, err := os.ReadFile(path)
 	if err != nil {
-		log.Warnf("Cannot read file: %+v", err)
-		err = errors.Wrap(err, "cannot read file")
+		err = errors.Wrap(err, "cannot read the configuration file")
 		return "", err
 	}
 
@@ -440,3 +449,12 @@ func IsSocket(path string) bool {
 	}
 	return s.Mode().Type() == fs.ModeSocket
 }
+
+// Convenience function returning nil when an input string parameter
+// is nil or empty.
+func NullifyEmptyString(s *string) *string {
+	if s != nil && len(*s) > 0 {
+		return s
+	}
+	return nil
+}
