@@ -1,13 +1,6 @@
 from core.compose_factory import create_docker_compose
 
 
-def test_fetch_empty_logs():
-    compose = create_docker_compose()
-    stdout, stderr = compose.logs()
-    assert stderr == ""
-    assert stdout != ""
-
-
 def test_server_instance():
     service_name = "server"
     compose = create_docker_compose()
@@ -16,7 +9,7 @@ def test_server_instance():
     state = compose.get_service_state(service_name)
     assert state.is_running()
     assert state.is_healthy()
-    compose.stop()
+    compose.down()
 
 
 def test_kea_only_instance():
@@ -28,4 +21,4 @@ def test_kea_only_instance():
     state = compose.get_service_state(service_name)
     assert state.is_running()
     assert state.is_healthy()
-    compose.stop()
+    compose.down()
