@@ -82,11 +82,21 @@ const routes: Routes = [
     },
     {
         path: 'dhcp/subnets',
+        pathMatch: 'full',
+        redirectTo: 'dhcp/subnets/all',
+    },
+    {
+        path: 'dhcp/subnets/:id',
         component: SubnetsPageComponent,
         canActivate: [AuthGuard],
     },
     {
         path: 'dhcp/shared-networks',
+        pathMatch: 'full',
+        redirectTo: 'dhcp/shared-networks/all',
+    },
+    {
+        path: 'dhcp/shared-networks/:id',
         component: SharedNetworksPageComponent,
         canActivate: [AuthGuard],
     },
