@@ -1,5 +1,5 @@
 import { Injectable } from '@angular/core'
-import { Router, CanActivate, ActivatedRouteSnapshot, RouterStateSnapshot, UrlTree } from '@angular/router'
+import { Router, ActivatedRouteSnapshot, RouterStateSnapshot, UrlTree } from '@angular/router'
 import { Observable } from 'rxjs'
 
 import { AuthService } from './auth.service'
@@ -7,11 +7,14 @@ import { AuthService } from './auth.service'
 @Injectable({
     providedIn: 'root',
 })
-export class AuthGuard implements CanActivate {
+export class AuthGuard {
     isAppInitialized = false
     user: any
 
-    constructor(private router: Router, private auth: AuthService) {}
+    constructor(
+        private router: Router,
+        private auth: AuthService
+    ) {}
 
     /** Indicates if a user has a permission to activate a given route. */
     canActivate(
