@@ -13,6 +13,8 @@ import { IPType } from '../iptype'
 import { DHCPOption } from '../backend/model/dHCPOption'
 import { DHCPOptionField } from '../backend/model/dHCPOptionField'
 import { StorkValidators } from '../validators'
+import { GenericFormService } from './generic-form.service'
+import { FormProcessor } from './form-processor'
 
 /**
  * A service for converting reactive forms with DHCP options to the REST API
@@ -21,29 +23,24 @@ import { StorkValidators } from '../validators'
 @Injectable({
     providedIn: 'root',
 })
-export class DhcpOptionSetFormService {
-    /**
-     * Form builder instance used by the service to create the reactive forms.
-     */
-    _formBuilder: UntypedFormBuilder
-
+export class DhcpOptionSetFormService extends FormProcessor {
     /**
      * Constructor.
      *
      * Creates form builder instance.
      */
     constructor() {
-        this._formBuilder = new UntypedFormBuilder()
+        super()
     }
 
     /**
      * Performs deep copy of the form array holding DHCP options or its fragment.
      *
-     * I copies all controls, including DhcpOptionFieldFormGroup, with their
+     * It copies all controls, including DhcpOptionFieldFormGroup, with their
      * validators. Controls belonging to forms or arrays are copied recursively.
      *
-     * This function implementation is derived from the following article:
-     * https://newbedev.com/deep-copy-of-angular-reactive-form
+     * It extends the generic function implemented in the base class with the
+     * support to copy DhcpOptionFieldFormGroup instances.
      *
      * @param control top-level control to be copied.
      * @returns copied control instance.
@@ -66,32 +63,14 @@ export class DhcpOptionSetFormService {
             })
 
             newControl = formGroup as any
-        } else if (control instanceof UntypedFormGroup) {
-            const formGroup = new UntypedFormGroup({}, control.validator, control.asyncValidator)
-            const controls = control.controls
 
-            Object.keys(controls).forEach((key) => {
-                formGroup.addControl(key, this.cloneControl(controls[key]))
-            })
-
-            newControl = formGroup as any
-        } else if (control instanceof UntypedFormArray) {
-            const formArray = new UntypedFormArray([], control.validator, control.asyncValidator)
-
-            control.controls.forEach((formControl) => formArray.push(this.cloneControl(formControl)))
-
-            newControl = formArray as any
-        } else if (control instanceof UntypedFormControl) {
-            newControl = new UntypedFormControl(control.value, control.validator, control.asyncValidator) as any
-        } else {
-            throw new Error('Error: unexpected control value')
+            if (control.disabled) {
+                newControl.disable({ emitEvent: false })
+            }
+            return newControl
         }
 
-        if (control.disabled) {
-            newControl.disable({ emitEvent: false })
-        }
-
-        return newControl
+        return super.cloneControl(control)
     }
 
     /**
@@ -257,8 +236,8 @@ export class DhcpOptionSetFormService {
                 // For each option field create an appropriate form group.
                 let fieldGroup: DhcpOptionFieldFormGroup
                 switch (field.fieldType as DhcpOptionFieldType) {
-                    case DhcpOptionFieldType.HexBytes:
-                        fieldGroup = this.createHexBytesField(field.values[0])
+                    case DhcpOptionFieldType.Binary:
+                        fieldGroup = this.createBinaryField(field.values[0])
                         break
                     case DhcpOptionFieldType.String:
                         fieldGroup = this.createStringField(field.values[0])
@@ -275,6 +254,15 @@ export class DhcpOptionSetFormService {
                     case DhcpOptionFieldType.Uint32:
                         fieldGroup = this.createUint32Field(field.values[0])
                         break
+                    case DhcpOptionFieldType.Int8:
+                        fieldGroup = this.createInt8Field(field.values[0])
+                        break
+                    case DhcpOptionFieldType.Int16:
+                        fieldGroup = this.createInt16Field(field.values[0])
+                        break
+                    case DhcpOptionFieldType.Int32:
+                        fieldGroup = this.createInt32Field(field.values[0])
+                        break
                     case DhcpOptionFieldType.IPv4Address:
                         fieldGroup = this.createIPv4AddressField(field.values[0])
                         break
@@ -352,14 +340,14 @@ export class DhcpOptionSetFormService {
     }
 
     /**
-     * Creates a control for option field using hex-bytes format.
+     * Creates a control for option field using binary format.
      *
      * @param value option field value to set.
      * @returns created form group instance.
      */
-    createHexBytesField(value: string = ''): DhcpOptionFieldFormGroup {
+    createBinaryField(value: string = ''): DhcpOptionFieldFormGroup {
         return this._createSimpleField(
-            DhcpOptionFieldType.HexBytes,
+            DhcpOptionFieldType.Binary,
             this._formBuilder.control(value, StorkValidators.hexIdentifier())
         )
     }
@@ -433,6 +421,36 @@ export class DhcpOptionSetFormService {
         )
     }
 
+    /**
+     * Creates a control for option field using int8 format.
+     *
+     * @param value option field value to set.
+     * @returns created form group instance.
+     */
+    createInt8Field(value: string | number | null = null): DhcpOptionFieldFormGroup {
+        return this._createSimpleField(DhcpOptionFieldType.Int8, this._formBuilder.control(value, Validators.required))
+    }
+
+    /**
+     * Creates a control for option field using int16 format.
+     *
+     * @param value option field value to set.
+     * @returns created form group instance.
+     */
+    createInt16Field(value: string | number | null = null): DhcpOptionFieldFormGroup {
+        return this._createSimpleField(DhcpOptionFieldType.Int16, this._formBuilder.control(value, Validators.required))
+    }
+
+    /**
+     * Creates a control for option field using int32 format.
+     *
+     * @param value option field value to set.
+     * @returns created form group instance.
+     */
+    createInt32Field(value: string | number | null = null): DhcpOptionFieldFormGroup {
+        return this._createSimpleField(DhcpOptionFieldType.Int32, this._formBuilder.control(value, Validators.required))
+    }
+
     /**
      * Creates a control for option field using IPv4 address format.
      *
@@ -465,7 +483,7 @@ export class DhcpOptionSetFormService {
      * @param value option field value to set.
      * @returns created form group instance.
      */
-    createIPv6PrefixField(prefix: string = '', prefixLen: string | number | null = 64): DhcpOptionFieldFormGroup {
+    createIPv6PrefixField(prefix: string = '', prefixLen: string | number | null = null): DhcpOptionFieldFormGroup {
         return this._createComplexField(DhcpOptionFieldType.IPv6Prefix, {
             prefix: this._formBuilder.control(prefix, [Validators.required, StorkValidators.ipv6()]),
             prefixLength: this._formBuilder.control(prefixLen, Validators.required),
