@@ -19,7 +19,7 @@ import { NoopAnimationsModule } from '@angular/platform-browser/animations'
 import { RouterTestingModule } from '@angular/router/testing'
 import { HumanCountComponent } from '../human-count/human-count.component'
 import { HumanCountPipe } from '../pipes/human-count.pipe'
-import { NumberPipe } from '../pipes/number.pipe'
+import { LocalNumberPipe } from '../pipes/local-number.pipe'
 import { HttpEvent } from '@angular/common/http'
 import { EntityLinkComponent } from '../entity-link/entity-link.component'
 import { MessageService } from 'primeng/api'
@@ -33,13 +33,7 @@ import { DelegatedPrefixBarComponent } from '../delegated-prefix-bar/delegated-p
 import { DividerModule } from 'primeng/divider'
 import { ChartModule } from 'primeng/chart'
 import { PlaceholderPipe } from '../pipes/placeholder.pipe'
-
-class MockParamMap {
-    /** Always returns null. */
-    get(name: string): string | null {
-        return null
-    }
-}
+import { MockParamMap } from '../utils'
 
 describe('SharedNetworksPageComponent', () => {
     let component: SharedNetworksPageComponent
@@ -80,7 +74,7 @@ describe('SharedNetworksPageComponent', () => {
                 HelpTipComponent,
                 HumanCountComponent,
                 HumanCountPipe,
-                NumberPipe,
+                LocalNumberPipe,
                 DelegatedPrefixBarComponent,
                 PlaceholderPipe,
                 SharedNetworksPageComponent,
@@ -125,7 +119,11 @@ describe('SharedNetworksPageComponent', () => {
                                         id: 1,
                                         machineAddress: 'localhost',
                                         machineHostname: 'lv-pc',
-                                        pools: ['1.0.0.4-1.0.255.254'],
+                                        pools: [
+                                            {
+                                                pool: '1.0.0.4-1.0.255.254',
+                                            },
+                                        ],
                                     },
                                 ],
                                 subnet: '1.0.0.0/16',
@@ -166,7 +164,11 @@ describe('SharedNetworksPageComponent', () => {
                                         id: 1,
                                         machineAddress: 'localhost',
                                         machineHostname: 'lv-pc',
-                                        pools: ['1.0.0.4-1.0.255.254'],
+                                        pools: [
+                                            {
+                                                pool: '1.0.0.4-1.0.255.254',
+                                            },
+                                        ],
                                     },
                                 ],
                                 subnet: '1.0.0.0/16',
