@@ -12,6 +12,8 @@ import {
     hasDifferentLocalSubnetOptions,
     extractUniqueSharedNetworkPools,
     hasDifferentLocalSharedNetworkOptions,
+    hasDifferentSubnetLevelOptions,
+    getStatisticValue,
 } from './subnets'
 
 describe('subnets', () => {
@@ -163,7 +165,20 @@ describe('subnets', () => {
                 subnet: '3000::/120',
                 localSubnets: [
                     {
-                        pools: ['3000::1-3000::5', '3000::10-3000::15', '3000::20-3000::35', '3000::40-3000::65'],
+                        pools: [
+                            {
+                                pool: '3000::1-3000::5',
+                            },
+                            {
+                                pool: '3000::10-3000::15',
+                            },
+                            {
+                                pool: '3000::20-3000::35',
+                            },
+                            {
+                                pool: '3000::40-3000::65',
+                            },
+                        ],
                         prefixDelegationPools: [
                             {
                                 prefix: '3001::/64',
@@ -182,7 +197,20 @@ describe('subnets', () => {
                         ],
                     },
                     {
-                        pools: ['3000::1-3000::5', '3000::10-3000::15', '3000::20-3000::35', '3000::70-3000::85'],
+                        pools: [
+                            {
+                                pool: '3000::1-3000::5',
+                            },
+                            {
+                                pool: '3000::10-3000::15',
+                            },
+                            {
+                                pool: '3000::20-3000::35',
+                            },
+                            {
+                                pool: '3000::70-3000::85',
+                            },
+                        ],
                         prefixDelegationPools: [
                             {
                                 prefix: '3001::/64',
@@ -209,11 +237,11 @@ describe('subnets', () => {
         expect(convertedSubnets[0].pools?.length).toBe(5)
         expect(convertedSubnets[0].prefixDelegationPools?.length).toBe(5)
 
-        expect(convertedSubnets[0].pools[0]).toBe('3000::1-3000::5')
-        expect(convertedSubnets[0].pools[1]).toBe('3000::10-3000::15')
-        expect(convertedSubnets[0].pools[2]).toBe('3000::20-3000::35')
-        expect(convertedSubnets[0].pools[3]).toBe('3000::40-3000::65')
-        expect(convertedSubnets[0].pools[4]).toBe('3000::70-3000::85')
+        expect(convertedSubnets[0].pools[0].pool).toBe('3000::1-3000::5')
+        expect(convertedSubnets[0].pools[1].pool).toBe('3000::10-3000::15')
+        expect(convertedSubnets[0].pools[2].pool).toBe('3000::20-3000::35')
+        expect(convertedSubnets[0].pools[3].pool).toBe('3000::40-3000::65')
+        expect(convertedSubnets[0].pools[4].pool).toBe('3000::70-3000::85')
 
         expect(convertedSubnets[0].prefixDelegationPools[0].prefix).toBe('3001::/64')
         expect(convertedSubnets[0].prefixDelegationPools[1].prefix).toBe('3001::/64')
@@ -228,7 +256,11 @@ describe('subnets', () => {
                 subnet: '192.0.2.0/24',
                 localSubnets: [
                     {
-                        pools: ['192.0.2.10-192.0.2.20'],
+                        pools: [
+                            {
+                                pool: '192.0.2.10-192.0.2.20',
+                            },
+                        ],
                     },
                 ],
             },
@@ -236,7 +268,11 @@ describe('subnets', () => {
                 subnet: '192.0.3.0/24',
                 localSubnets: [
                     {
-                        pools: ['192.0.3.10-192.0.3.20'],
+                        pools: [
+                            {
+                                pool: '192.0.3.10-192.0.3.20',
+                            },
+                        ],
                     },
                 ],
             },
@@ -244,7 +280,11 @@ describe('subnets', () => {
                 subnet: '192.0.4.0/24',
                 localSubnets: [
                     {
-                        pools: ['192.0.4.10-192.0.4.20'],
+                        pools: [
+                            {
+                                pool: '192.0.4.10-192.0.4.20',
+                            },
+                        ],
                     },
                 ],
             },
@@ -279,10 +319,21 @@ describe('subnets', () => {
             subnet: '192.0.2.0/24',
             localSubnets: [
                 {
-                    pools: ['192.0.2.10-192.0.2.20', '192.0.2.30-192.0.2.40'],
+                    pools: [
+                        {
+                            pool: '192.0.2.10-192.0.2.20',
+                        },
+                        {
+                            pool: '192.0.2.30-192.0.2.40',
+                        },
+                    ],
                 },
                 {
-                    pools: ['192.0.2.10-192.0.2.20'],
+                    pools: [
+                        {
+                            pool: '192.0.2.10-192.0.2.20',
+                        },
+                    ],
                 },
             ],
         }
@@ -296,7 +347,14 @@ describe('subnets', () => {
             subnet: '192.0.2.0/24',
             localSubnets: [
                 {
-                    pools: ['192.0.2.10-192.0.2.20', '192.0.2.30-192.0.2.40'],
+                    pools: [
+                        {
+                            pool: '192.0.2.10-192.0.2.20',
+                        },
+                        {
+                            pool: '192.0.2.30-192.0.2.40',
+                        },
+                    ],
                 },
                 {
                     pools: null,
@@ -418,7 +476,14 @@ describe('subnets', () => {
             subnet: '2001:db8:1::/64',
             localSubnets: [
                 {
-                    pools: ['2001:db8:1::20-2001:db8:1::40', '2001:db8:1::60-2001:db8:1::80'],
+                    pools: [
+                        {
+                            pool: '2001:db8:1::20-2001:db8:1::40',
+                        },
+                        {
+                            pool: '2001:db8:1::60-2001:db8:1::80',
+                        },
+                    ],
                     prefixDelegationPools: [
                         {
                             prefix: '3000::',
@@ -432,7 +497,14 @@ describe('subnets', () => {
                     ],
                 },
                 {
-                    pools: ['2001:db8:1::60-2001:db8:1::80', '2001:db8:1::20-2001:db8:1::40'],
+                    pools: [
+                        {
+                            pool: '2001:db8:1::60-2001:db8:1::80',
+                        },
+                        {
+                            pool: '2001:db8:1::20-2001:db8:1::40',
+                        },
+                    ],
                     prefixDelegationPools: [
                         {
                             prefix: '3000:1::',
@@ -485,6 +557,7 @@ describe('subnets', () => {
             ],
         }
         expect(hasDifferentLocalSubnetOptions(subnet)).toBeTrue()
+        expect(hasDifferentSubnetLevelOptions(subnet)).toBeFalse()
     })
 
     it('detects different options for servers for the null hash', () => {
@@ -520,6 +593,7 @@ describe('subnets', () => {
             ],
         }
         expect(hasDifferentLocalSubnetOptions(subnet)).toBeTrue()
+        expect(hasDifferentSubnetLevelOptions(subnet)).toBeFalse()
     })
 
     it('detects different options for servers for the null parameters', () => {
@@ -553,7 +627,9 @@ describe('subnets', () => {
             ],
         }
         expect(hasDifferentLocalSubnetOptions(subnet)).toBeTrue()
+        expect(hasDifferentSubnetLevelOptions(subnet)).toBeFalse()
     })
+
     it('detects different options for servers for non-existing parameters', () => {
         const subnet = {
             subnet: '192.0.2.0/24',
@@ -584,6 +660,7 @@ describe('subnets', () => {
             ],
         }
         expect(hasDifferentLocalSubnetOptions(subnet)).toBeTrue()
+        expect(hasDifferentSubnetLevelOptions(subnet)).toBeFalse()
     })
 
     it('detects the same options for servers', () => {
@@ -619,6 +696,7 @@ describe('subnets', () => {
             ],
         }
         expect(hasDifferentLocalSubnetOptions(subnet)).toBeFalse()
+        expect(hasDifferentSubnetLevelOptions(subnet)).toBeFalse()
     })
 
     it('detects the same options for servers for null hashes', () => {
@@ -654,6 +732,43 @@ describe('subnets', () => {
             ],
         }
         expect(hasDifferentLocalSubnetOptions(subnet)).toBeFalse()
+        expect(hasDifferentSubnetLevelOptions(subnet)).toBeFalse()
+    })
+
+    it('detects different subnet level options', () => {
+        const subnet = {
+            subnet: '192.0.2.0/24',
+            localSubnets: [
+                {
+                    keaConfigSubnetParameters: {
+                        subnetLevelParameters: {
+                            optionsHash: '123',
+                        },
+                        sharedNetworkLevelParameters: {
+                            optionsHash: '234',
+                        },
+                        globalParameters: {
+                            optionsHash: '345',
+                        },
+                    },
+                },
+                {
+                    keaConfigSubnetParameters: {
+                        subnetLevelParameters: {
+                            optionsHash: '234',
+                        },
+                        sharedNetworkLevelParameters: {
+                            optionsHash: '234',
+                        },
+                        globalParameters: {
+                            optionsHash: '345',
+                        },
+                    },
+                },
+            ],
+        }
+        expect(hasDifferentLocalSubnetOptions(subnet)).toBeTrue()
+        expect(hasDifferentSubnetLevelOptions(subnet)).toBeTrue()
     })
 
     it('extracts unique pools from a shared network', () => {
@@ -666,10 +781,18 @@ describe('subnets', () => {
                         localSubnets: [
                             {
                                 pools: [
-                                    '3000::1-3000::5',
-                                    '3000::10-3000::15',
-                                    '3000::20-3000::35',
-                                    '3000::40-3000::65',
+                                    {
+                                        pool: '3000::1-3000::5',
+                                    },
+                                    {
+                                        pool: '3000::10-3000::15',
+                                    },
+                                    {
+                                        pool: '3000::20-3000::35',
+                                    },
+                                    {
+                                        pool: '3000::40-3000::65',
+                                    },
                                 ],
                                 prefixDelegationPools: [
                                     {
@@ -690,10 +813,18 @@ describe('subnets', () => {
                             },
                             {
                                 pools: [
-                                    '3000::1-3000::5',
-                                    '3000::10-3000::15',
-                                    '3000::20-3000::35',
-                                    '3000::70-3000::85',
+                                    {
+                                        pool: '3000::1-3000::5',
+                                    },
+                                    {
+                                        pool: '3000::10-3000::15',
+                                    },
+                                    {
+                                        pool: '3000::20-3000::35',
+                                    },
+                                    {
+                                        pool: '3000::70-3000::85',
+                                    },
                                 ],
                                 prefixDelegationPools: [
                                     {
@@ -723,11 +854,11 @@ describe('subnets', () => {
         expect(convertedSharedNetworks[0].pools?.length).toBe(5)
         expect(convertedSharedNetworks[0].prefixDelegationPools?.length).toBe(5)
 
-        expect(convertedSharedNetworks[0].pools[0]).toBe('3000::1-3000::5')
-        expect(convertedSharedNetworks[0].pools[1]).toBe('3000::10-3000::15')
-        expect(convertedSharedNetworks[0].pools[2]).toBe('3000::20-3000::35')
-        expect(convertedSharedNetworks[0].pools[3]).toBe('3000::40-3000::65')
-        expect(convertedSharedNetworks[0].pools[4]).toBe('3000::70-3000::85')
+        expect(convertedSharedNetworks[0].pools[0].pool).toBe('3000::1-3000::5')
+        expect(convertedSharedNetworks[0].pools[1].pool).toBe('3000::10-3000::15')
+        expect(convertedSharedNetworks[0].pools[2].pool).toBe('3000::20-3000::35')
+        expect(convertedSharedNetworks[0].pools[3].pool).toBe('3000::40-3000::65')
+        expect(convertedSharedNetworks[0].pools[4].pool).toBe('3000::70-3000::85')
 
         expect(convertedSharedNetworks[0].prefixDelegationPools[0].prefix).toBe('3001::/64')
         expect(convertedSharedNetworks[0].prefixDelegationPools[1].prefix).toBe('3001::/64')
@@ -746,10 +877,18 @@ describe('subnets', () => {
                         localSubnets: [
                             {
                                 pools: [
-                                    '3000::1-3000::5',
-                                    '3000::10-3000::15',
-                                    '3000::20-3000::35',
-                                    '3000::40-3000::65',
+                                    {
+                                        pool: '3000::1-3000::5',
+                                    },
+                                    {
+                                        pool: '3000::10-3000::15',
+                                    },
+                                    {
+                                        pool: '3000::20-3000::35',
+                                    },
+                                    {
+                                        pool: '3000::40-3000::65',
+                                    },
                                 ],
                                 prefixDelegationPools: [
                                     {
@@ -780,10 +919,18 @@ describe('subnets', () => {
                         localSubnets: [
                             {
                                 pools: [
-                                    '3000::1-3000::5',
-                                    '3000::10-3000::15',
-                                    '3000::20-3000::35',
-                                    '3000::70-3000::85',
+                                    {
+                                        pool: '3000::1-3000::5',
+                                    },
+                                    {
+                                        pool: '3000::10-3000::15',
+                                    },
+                                    {
+                                        pool: '3000::20-3000::35',
+                                    },
+                                    {
+                                        pool: '3000::70-3000::85',
+                                    },
                                 ],
                                 prefixDelegationPools: [
                                     {
@@ -900,6 +1047,7 @@ describe('subnets', () => {
         }
         expect(hasDifferentLocalSharedNetworkOptions(sharedNetwork)).toBeTrue()
     })
+
     it('detects different shared network options for servers for non-existing parameters', () => {
         const sharedNetwork = {
             name: 'foo',
@@ -983,4 +1131,39 @@ describe('subnets', () => {
         }
         expect(hasDifferentLocalSharedNetworkOptions(sharedNetwork)).toBeFalse()
     })
+
+    it('should extract the total addresses', () => {
+        // Missing stats.
+        expect(getTotalAddresses({})).toBeNull()
+        // Empty stats.
+        expect(getTotalAddresses({ stats: {} })).toBeUndefined()
+        // IPv4 stats.
+        expect(getTotalAddresses({ stats: { 'total-addresses': 42 } })).toBe(42)
+        // IPv6 stats.
+        expect(getTotalAddresses({ stats: { 'total-nas': 42 } })).toBe(42)
+    })
+
+    it('should extract the assigned addresses', () => {
+        // Missing stats.
+        expect(getAssignedAddresses({})).toBeNull()
+        // Empty stats.
+        expect(getAssignedAddresses({ stats: {} })).toBeUndefined()
+        // IPv4 stats.
+        expect(getAssignedAddresses({ stats: { 'assigned-addresses': 42 } })).toBe(42)
+        // IPv6 stats.
+        expect(getAssignedAddresses({ stats: { 'assigned-nas': 42 } })).toBe(42)
+    })
+
+    it('should extract statistic by name', () => {
+        // Missing stats.
+        expect(getStatisticValue({}, 'foo')).toBeNull()
+        // Empty stats.
+        expect(getStatisticValue({ stats: {} }, 'foo')).toBeNull()
+        // Big int value.
+        expect(getStatisticValue({ stats: { foo: BigInt(42) } }, 'foo')).toBe(42n)
+        // Numeric value.
+        expect(getStatisticValue({ stats: { foo: 42 } }, 'foo')).toBe(42n)
+        // String value.
+        expect(getStatisticValue({ stats: { foo: '42' } }, 'foo')).toBeNull()
+    })
 })
